#!/usr/bin/python3 -B
from libsecp256k1_0 import Secp265k1

def test_main():
	print(Secp265k1._load)

if __name__ == '__main__':
	raise SystemExit(test_main())